import os
import click
from jira import JIRA
from jiracmd import worklog

@click.group()
@click.version_option()
@click.pass_context
def cli(ctx):
    USERNAME = os.getenv('JIRA_USERNAME')
    API_TOKEN = os.getenv('JIRA_API_TOKEN')
    SERVER = os.getenv('JIRA_SERVER')
    ctx.obj = JIRA(server=SERVER, basic_auth=(USERNAME, API_TOKEN))

@click.group(name="worklog")
def cli_worklog():
    pass

@click.group(name="issue")
def cli_issue():
    pass 

@click.command(name="add")
@click.option('-i', '--issue')
@click.option('-s', '--start')
@click.option('-e', '--end')
@click.option('-d', '--date')
@click.option('-t', '--time-spent')
@click.pass_obj
def worklog_add(jira, issue, start, end, date, time_spent):
    click.echo(f'== Worklog: add {issue} on {date} {start}')
    worklog.add()

@click.command(name="list")
@click.pass_obj
@click.option('-i', '--issue')
def worklog_list(jira, issue):
    click.echo(':: Worklog List')
    click.echo(jira)
    worklog.list()


cli.add_command(cli_worklog)
cli.add_command(cli_issue)
cli_worklog.add_command(worklog_list)
cli_worklog.add_command(worklog_add)





if __name__ == "__main__":
    cli()



from setuptools import setup
import os

VERSION = "0.0.3"


def get_long_description():
    with open(
        os.path.join(os.path.dirname(os.path.abspath(__file__)), "README.md"),
        encoding="utf8",
    ) as fp:
        return fp.read()


setup(
    name="jiracmd",
    description="Jira Command Line Tool",
    long_description=get_long_description(),
    long_description_content_type="text/markdown",
    author="Rafael Fernandes Sant'Anna",
    url="https://github.com/rfsantanna/jiracmd",
    project_urls={
        "Issues": "https://github.com/rfsantanna/jiracmd/issues",
        "CI": "https://github.com/rfsantanna/jiracmd/actions",
        "Changelog": "https://github.com/rfsantanna/jiracmd/releases",
    },
    license="Apache License, Version 2.0",
    version=VERSION,
    packages=["jiracmd"],
    entry_points="""
        [console_scripts]
        jiracmd=jiracmd.cli:cli
    """,
    install_requires=["click", "jira"],
    extras_require={
        "test": ["pytest"]
    },
    python_requires=">=3.6",
)
